@@ -7,7 +7,6 @@ from . import page
 
 
 class InstanceGroup(HasCreate, base.Base):
-
     def add_instance(self, instance):
         with suppress(exc.NoContent):
             self.related.instances.post(dict(id=instance.id))
@@ -17,8 +16,7 @@ class InstanceGroup(HasCreate, base.Base):
             self.related.instances.post(dict(id=instance.id, disassociate=True))
 
     def payload(self, **kwargs):
-        payload = PseudoNamespace(name=kwargs.get('name') or
-                                  'Instance Group - {}'.format(random_title()))
+        payload = PseudoNamespace(name=kwargs.get('name') or 'Instance Group - {}'.format(random_title()))
         fields = ('policy_instance_percentage', 'policy_instance_minimum', 'policy_instance_list', 'is_container_group')
         update_payload(payload, fields, kwargs)
 
@@ -35,8 +33,7 @@ class InstanceGroup(HasCreate, base.Base):
         return self.update_identity(InstanceGroups(self.connection).post(payload))
 
 
-page.register_page([resources.instance_group,
-                    (resources.instance_groups, 'post')], InstanceGroup)
+page.register_page([resources.instance_group, (resources.instance_groups, 'post')], InstanceGroup)
 
 
 class InstanceGroups(page.PageList, InstanceGroup):
@@ -44,5 +41,4 @@ class InstanceGroups(page.PageList, InstanceGroup):
     pass
 
 
-page.register_page([resources.instance_groups,
-                    resources.related_instance_groups], InstanceGroups)
+page.register_page([resources.instance_groups, resources.related_instance_groups], InstanceGroups)
