@@ -15,12 +15,9 @@ class WorkflowJobTemplateNode(HasCreate, base.Base):
     def payload(self, workflow_job_template, unified_job_template, **kwargs):
         if not unified_job_template:
             # May pass "None" to explicitly create an approval node
-            payload = PseudoNamespace(
-                workflow_job_template=workflow_job_template.id)
+            payload = PseudoNamespace(workflow_job_template=workflow_job_template.id)
         else:
-            payload = PseudoNamespace(
-                workflow_job_template=workflow_job_template.id,
-                unified_job_template=unified_job_template.id)
+            payload = PseudoNamespace(workflow_job_template=workflow_job_template.id, unified_job_template=unified_job_template.id)
 
         optional_fields = (
             'diff_mode',
@@ -33,7 +30,8 @@ class WorkflowJobTemplateNode(HasCreate, base.Base):
             'verbosity',
             'extra_data',
             'identifier',
-            'all_parents_must_converge')
+            'all_parents_must_converge',
+        )
 
         update_payload(payload, optional_fields, kwargs)
 
@@ -42,45 +40,23 @@ class WorkflowJobTemplateNode(HasCreate, base.Base):
 
         return payload
 
-    def create_payload(
-            self,
-            workflow_job_template=WorkflowJobTemplate,
-            unified_job_template=JobTemplate,
-            **kwargs):
+    def create_payload(self, workflow_job_template=WorkflowJobTemplate, unified_job_template=JobTemplate, **kwargs):
         if not unified_job_template:
             self.create_and_update_dependencies(workflow_job_template)
-            payload = self.payload(
-                workflow_job_template=self.ds.workflow_job_template,
-                unified_job_template=None,
-                **kwargs)
+            payload = self.payload(workflow_job_template=self.ds.workflow_job_template, unified_job_template=None, **kwargs)
         else:
-            self.create_and_update_dependencies(
-                workflow_job_template, unified_job_template)
-            payload = self.payload(
-                workflow_job_template=self.ds.workflow_job_template,
-                unified_job_template=self.ds.unified_job_template,
-                **kwargs)
+            self.create_and_update_dependencies(workflow_job_template, unified_job_template)
+            payload = self.payload(workflow_job_template=self.ds.workflow_job_template, unified_job_template=self.ds.unified_job_template, **kwargs)
         payload.ds = DSAdapter(self.__class__.__name__, self._dependency_store)
         return payload
 
-    def create(
-            self,
-            workflow_job_template=WorkflowJobTemplate,
-            unified_job_template=JobTemplate,
-            **kwargs):
-        payload = self.create_payload(
-            workflow_job_template=workflow_job_template,
-            unified_job_template=unified_job_template,
-            **kwargs)
-        return self.update_identity(
-            WorkflowJobTemplateNodes(
-                self.connection).post(payload))
+    def create(self, workflow_job_template=WorkflowJobTemplate, unified_job_template=JobTemplate, **kwargs):
+        payload = self.create_payload(workflow_job_template=workflow_job_template, unified_job_template=unified_job_template, **kwargs)
+        return self.update_identity(WorkflowJobTemplateNodes(self.connection).post(payload))
 
     def _add_node(self, endpoint, unified_job_template, **kwargs):
-        node = endpoint.post(
-            dict(unified_job_template=unified_job_template.id, **kwargs))
-        node.create_and_update_dependencies(
-            self.ds.workflow_job_template, unified_job_template)
+        node = endpoint.post(dict(unified_job_template=unified_job_template.id, **kwargs))
+        node.create_and_update_dependencies(self.ds.workflow_job_template, unified_job_template)
         return node
 
     def add_always_node(self, unified_job_template, **kwargs):
@@ -94,24 +70,18 @@ class WorkflowJobTemplateNode(HasCreate, base.Base):
 
     def add_credential(self, credential):
         with suppress(exc.NoContent):
-            self.related.credentials.post(
-                dict(id=credential.id, associate=True))
+            self.related.credentials.post(dict(id=credential.id, associate=True))
 
     def remove_credential(self, credential):
         with suppress(exc.NoContent):
-            self.related.credentials.post(
-                dict(id=credential.id, disassociate=True))
+            self.related.credentials.post(dict(id=credential.id, disassociate=True))
 
     def remove_all_credentials(self):
         for cred in self.related.credentials.get().results:
             with suppress(exc.NoContent):
-                self.related.credentials.post(
-                    dict(id=cred.id, disassociate=True))
+                self.related.credentials.post(dict(id=cred.id, disassociate=True))
 
-    def make_approval_node(
-        self,
-        **kwargs
-    ):
+    def make_approval_node(self, **kwargs):
         if 'name' not in kwargs:
             kwargs['name'] = 'approval node {}'.format(random_title())
         self.related.create_approval_template.post(kwargs)
@@ -122,10 +92,10 @@ class WorkflowJobTemplateNode(HasCreate, base.Base):
         return candidates.results.pop()
 
 
-page.register_page([resources.workflow_job_template_node,
-                    (resources.workflow_job_template_nodes, 'post'),
-                    (resources.workflow_job_template_workflow_nodes, 'post')],
-                   WorkflowJobTemplateNode)
+page.register_page(
+    [resources.workflow_job_template_node, (resources.workflow_job_template_nodes, 'post'), (resources.workflow_job_template_workflow_nodes, 'post')],
+    WorkflowJobTemplateNode,
+)
 
 
 class WorkflowJobTemplateNodes(page.PageList, WorkflowJobTemplateNode):
@@ -133,9 +103,13 @@ class WorkflowJobTemplateNodes(page.PageList, WorkflowJobTemplateNode):
     pass
 
 
-page.register_page([resources.workflow_job_template_nodes,
-                    resources.workflow_job_template_workflow_nodes,
-                    resources.workflow_job_template_node_always_nodes,
-                    resources.workflow_job_template_node_failure_nodes,
-                    resources.workflow_job_template_node_success_nodes],
-                   WorkflowJobTemplateNodes)
+page.register_page(
+    [
+        resources.workflow_job_template_nodes,
+        resources.workflow_job_template_workflow_nodes,
+        resources.workflow_job_template_node_always_nodes,
+        resources.workflow_job_template_node_failure_nodes,
+        resources.workflow_job_template_node_success_nodes,
+    ],
+    WorkflowJobTemplateNodes,
+)
